mercurial/localrepo.py
changeset 45015 5797dbb630df
parent 44943 9e5b4dbe8ff2
child 45064 41b32cbc53f8
--- a/mercurial/localrepo.py	Thu Jun 25 13:37:56 2020 -0700
+++ b/mercurial/localrepo.py	Thu Jun 25 12:02:34 2020 -0700
@@ -1235,8 +1235,9 @@
             if path.startswith(b'cache/'):
                 msg = b'accessing cache with vfs instead of cachevfs: "%s"'
                 repo.ui.develwarn(msg % path, stacklevel=3, config=b"cache-vfs")
-            if path.startswith(b'journal.') or path.startswith(b'undo.'):
-                # journal is covered by 'lock'
+            # path prefixes covered by 'lock'
+            vfs_path_prefixes = (b'journal.', b'undo.', b'strip-backup/')
+            if any(path.startswith(prefix) for prefix in vfs_path_prefixes):
                 if repo._currentlock(repo._lockref) is None:
                     repo.ui.develwarn(
                         b'write with no lock: "%s"' % path,